@@ -123,14 +123,13 @@ class MetricViewer:
         else:
             from dash import Input, Output, html, dcc, dash_table
 
-        if include is None:
-            include = []
-        if exclude is None:
-            exclude = []
-
         df = self.table
-        df = df.drop(exclude, axis=1)
-        df = df[['line', 'num'] + include]
+        if exclude is not None:
+            df = df.drop(exclude, axis=1)
+
+        if include is not None:
+            df = df[['line', 'num'] + include]
+
         df_flatten = pd.DataFrame(map(flatten, df.to_dict('records')))
 
         app = dash.Dash()
