@@ -13,32 +13,25 @@ limitations under the License.
 
 import os
 import sys
-import json
-import shutil
-import unittest
-from unittest import TestCase
+import pytest
 
 MODULE_PATH = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
 sys.path.append(os.path.dirname(MODULE_PATH))
 
-from cascade.tests.number_dataset import NumberDataset
+from cascade.data import Wrapper
 from cascade.meta import MetaValidator, DataValidationException
 
 
-class TestMetaValidator(TestCase):
-    def pipeline_run(self, arr):
-        ds = NumberDataset(arr)
-        ds = MetaValidator(ds)
-
-    def test_true(self):
-        self.pipeline_run([1, 2, 3, 4, 5])
-        self.pipeline_run([1, 2, 3, 4, 5])
-
-    def test_raise(self):
-        self.pipeline_run([1, 2, 3, 4, 5])
-        with self.assertRaises(DataValidationException):
-            self.pipeline_run([1, 2, 3, 4, 5, 6])
+def pipeline_run(ds, root):
+    MetaValidator(ds, root=root)
 
 
-if __name__ == '__main__':
-    unittest.main()
+def test_true(number_dataset, tmp_path):
+    pipeline_run(number_dataset, str(tmp_path))
+    pipeline_run(number_dataset, str(tmp_path))
+
+
+def test_raise(tmp_path):
+    pipeline_run(Wrapper([1, 2, 3, 4, 5]), str(tmp_path))
+    with pytest.raises(DataValidationException):
+        pipeline_run(Wrapper([1, 2, 3, 4, 5, 6]), str(tmp_path))
