@@ -16,25 +16,22 @@ limitations under the License.
 
 import os
 import sys
-import unittest
-from unittest import TestCase
+import pytest
 
 MODULE_PATH = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
 sys.path.append(os.path.dirname(MODULE_PATH))
 
-from cascade.data import RandomSampler
-from cascade.tests.number_dataset import NumberDataset
+from cascade.data import RandomSampler, Wrapper
 
+@pytest.mark.parametrize(
+    'arr', [
+        ([1, 2, 3, 4, 5],),
+        ([1, 5],),
+        ([1, 2, -3],)
+    ]
+)
+def test(arr):
+   ds = Wrapper(arr)
+   ds = RandomSampler(ds)
 
-class TestRandomSampler(TestCase):
-    def test(self):
-        ds = NumberDataset([0, 1, 2, 3, 4])
-        ds = RandomSampler(ds)
-
-        self.assertNotEqual(
-            [ds[i] for i in range(len(ds))],
-            [0, 1, 2, 3, 4])
-
-
-if __name__ == '__main__':
-    unittest.main()
+   assert([ds[i] for i in range(len(ds))] != arr)
