@@ -20,6 +20,15 @@ from tqdm import trange
 
 
 class OverSampler(Sampler):
+    """
+    Accepts datasets which return tuples of objects and labels.
+    Isn't lazy - runs through all the items ones to determine key order. 
+    Doesn't store values afterwards.
+
+    To oversample it repeats items with minority labels for the amount
+    of times needed to make equal distribution. 
+    Works for any number of classes.
+    """
     def __init__(self, dataset, *args, **kwargs):
         labels = [int(dataset[i][1]) for i in trange(len(dataset))]
         ulabels = np.unique(labels)
