@@ -14,7 +14,6 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import warnings
 from .sk_model import SkModel
 
 
@@ -23,5 +22,4 @@ class SkClassifier(SkModel):
     Alias for cascade.utils.SkModel remained for compatibility
     """
     def __init__(self, name=None, blocks=[], **kwargs):
-        warnings.warn('SkClassifier is an alias of SkModel and doesn\'t have any additional capabilities')
-        super().__init__(name=name, blocks=blocks, **kwargs)
+        raise RuntimeError('SkClassifier is not supported anymore.\n It was an alias of SkModel and doesn\'t have any additional capabilities.\nPlease, replace SkClassifier with SkModel.')
